% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/reconstructShapePPP.R
\name{reconstructShapeDensityImage}
\alias{reconstructShapeDensityImage}
\title{Reconstruct structure from spe object with given image id}
\usage{
reconstructShapeDensityImage(
  spe,
  marks,
  image_col,
  image_id,
  mark_select,
  dim = 500,
  bndw = NULL,
  thres = NULL
)
}
\arguments{
\item{spe}{SpatialExperiment; a object of class \code{SpatialExperiment}}

\item{marks}{character; name of column in \code{colData} that will correspond
to the \code{ppp} marks}

\item{image_col}{character; name of a column in \code{colData} that corresponds
to the image}

\item{image_id}{character; image id, must be present in image_col}

\item{mark_select}{character; name of mark that is to be selected for the
reconstruction}

\item{dim}{numeric; x dimension of the final reconstruction.
A lower resolution speed up computation but lead to less exact reconstruction.
Default = 500}

\item{bndw}{numeric; bandwith of the sigma parameter in the density estimation,
if no value is given the bandwith is estimated using cross validation with
the \code{bw.diggle} function.}

\item{thres}{numeric; intensity threshold for the reconstruction}
}
\value{
sf object of class \code{POLYGON}
}
\description{
Reconstruct structure from spe object with given image id
}
\examples{
spe <- imcdatasets::Damond_2019_Pancreas("spe", full_dataset = FALSE)
islet_poly <- reconstructShapeDensityImage(spe,
    marks = "cell_category",
    image_col = "image_name", image_id = "E04", mark_select = "islet", dim = 500
)
plot(islet_poly)
}
