% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/reconstructShapePPP.R
\name{reconstructShapeDensitySPE}
\alias{reconstructShapeDensitySPE}
\title{Reconstruct structure from spatial experiment object per image id}
\usage{
reconstructShapeDensitySPE(
  spe,
  marks,
  image_col,
  mark_select,
  dim = 500,
  bndw = NULL,
  thres,
  ncores = 1
)
}
\arguments{
\item{spe}{SpatialExperiment; a object of class \code{SpatialExperiment}}

\item{marks}{character; name of column in \code{colData} that will correspond
to the \code{ppp} marks}

\item{image_col}{character; name of a column in \code{colData} that corresponds
to the image}

\item{mark_select}{character; name of mark that is to be selected for the
reconstruction}

\item{dim}{numeric; x dimension of the final reconstruction.
A lower resolution speed up computation but lead to less exact reconstruction.
Default = 500}

\item{bndw}{numeric; bandwith of the sigma parameter in the density estimation,
if no value is given the bandwith is estimated using cross validation with
the \code{bw.diggle} function.}

\item{thres}{numeric; intensity threshold for the reconstruction}

\item{ncores}{numeric; number of cores for parallel processing using
\code{mclapply}. Default = 1}
}
\value{
simple feature collection
}
\description{
Reconstruct structure from spatial experiment object per image id
}
\examples{
spe <- imcdatasets::Damond_2019_Pancreas("spe", full_dataset = FALSE)
spe_sel <- spe[, spe[["image_name"]] \%in\% c("E02", "E03", "E04")]
all_islets <- reconstructShapeDensitySPE(spe_sel,
    marks = "cell_category",
    image_col = "image_name", mark_select = "islet", bndw = sigma, thres = 0.0025
)
all_islets
}
